==> redmine-2.6.4.tar.gz: redmine-2.6.4/test/integration/routing/workflows_test.rb <==
# Redmine - project management software
# Copyright (C) 2006-2015  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require File.expand_path('../../../test_helper', __FILE__)

class RoutingWorkflowsTest < ActionController::IntegrationTest
  def test_workflows
    assert_routing(
        { :method => 'get', :path => "/workflows" },
        { :controller => 'workflows', :action => 'index' }
      )
    ["get", "post"].each do |method|
      assert_routing(
          { :method => method, :path => "/workflows/edit" },
          { :controller => 'workflows', :action => 'edit' }
        )
    end
    ["get", "post"].each do |method|
      assert_routing(
          { :method => method, :path => "/workflows/permissions" },
          { :controller => 'workflows', :action => 'permissions' }
        )
    end
    ["get", "post"].each do |method|
      assert_routing(
          { :method => method, :path => "/workflows/copy" },
          { :controller => 'workflows', :action => 'copy' }
        )
    end
  end
end

==> redmine_3.0~20140825.orig.tar.gz: redmine-3.0~20140825/test/integration/routing/workflows_test.rb <==
# Redmine - project management software
# Copyright (C) 2006-2014  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require File.expand_path('../../../test_helper', __FILE__)

class RoutingWorkflowsTest < ActionDispatch::IntegrationTest
  def test_workflows
    assert_routing(
        { :method => 'get', :path => "/workflows" },
        { :controller => 'workflows', :action => 'index' }
      )
    ["get", "post"].each do |method|
      assert_routing(
          { :method => method, :path => "/workflows/edit" },
          { :controller => 'workflows', :action => 'edit' }
        )
    end
    ["get", "post"].each do |method|
      assert_routing(
          { :method => method, :path => "/workflows/permissions" },
          { :controller => 'workflows', :action => 'permissions' }
        )
    end
    ["get", "post"].each do |method|
      assert_routing(
          { :method => method, :path => "/workflows/copy" },
          { :controller => 'workflows', :action => 'copy' }
        )
    end
  end
end
